@@ -14,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 
 class MattermostBot(OutputChannel):
-    """A Mattermost communication channel"""
+    """A Mattermost communication channel."""
 
     @classmethod
     def name(cls) -> Text:
@@ -23,7 +23,6 @@ class MattermostBot(OutputChannel):
     @classmethod
     def token_from_login(cls, url: Text, user: Text, password: Text) -> Optional[Text]:
         """Retrieve access token for mattermost user."""
-
         data = {"login_id": user, "password": password}
         r = requests.post(url + "/users/login", data=json.dumps(data))
         if r.status_code == 200:
@@ -49,7 +48,6 @@ class MattermostBot(OutputChannel):
 
     def _post_data_to_channel(self, data: Dict[Text, Any]) -> Response:
         """Send a message to a mattermost channel."""
-
         headers = {"Authorization": "Bearer " + self.token}
         r = requests.post(self.url + "/posts", headers=headers, data=json.dumps(data))
         if not r.status_code == 200:
@@ -77,7 +75,6 @@ class MattermostBot(OutputChannel):
         self, recipient_id: Text, image: Text, **kwargs: Any
     ) -> None:
         """Sends an image."""
-
         self._post_data_to_channel(
             {
                 "channel_id": self.bot_channel,
@@ -94,7 +91,7 @@ class MattermostBot(OutputChannel):
     ) -> None:
         """Sends buttons to the output."""
         # buttons are a list of objects: [(option_name, payload)]
-        # See https://docs.mattermost.com/developer/interactive-messages.html#message-buttons # noqa: E501, W505
+        # See https://docs.mattermost.com/developer/interactive-messages.html#message-buttons # noqa: E501
 
         actions = [
             {
