@@ -1,42 +1,67 @@
-from typing import Any, Dict, List, Text
+from __future__ import annotations
+from typing import Any, Dict, List, Optional, Text
 
 import regex
 
 import rasa.shared.utils.io
 import rasa.utils.io
-from rasa.shared.constants import DOCS_URL_COMPONENTS
+
+from rasa.engine.graph import ExecutionContext
+from rasa.engine.recipes.default_recipe import DefaultV1Recipe
+from rasa.engine.storage.resource import Resource
+from rasa.engine.storage.storage import ModelStorage
 from rasa.nlu.tokenizers.tokenizer import Token, Tokenizer
+from rasa.shared.constants import DOCS_URL_COMPONENTS
 from rasa.shared.nlu.training_data.message import Message
 
 
+@DefaultV1Recipe.register(
+    DefaultV1Recipe.ComponentType.MESSAGE_TOKENIZER, is_trainable=False
+)
 class WhitespaceTokenizer(Tokenizer):
+    """Creates features for entity extraction."""
 
-    defaults = {
-        # Flag to check whether to split intents
-        "intent_tokenization_flag": False,
-        # Symbol on which intent should be split
-        "intent_split_symbol": "_",
-        # Regular expression to detect tokens
-        "token_pattern": None,
-    }
+    @staticmethod
+    def not_supported_languages() -> Optional[List[Text]]:
+        """The languages that are not supported."""
+        return ["zh", "ja", "th"]
 
-    # the following language should not be tokenized using the WhitespaceTokenizer
-    not_supported_language_list = ["zh", "ja", "th"]
-
-    def __init__(self, component_config: Dict[Text, Any] = None) -> None:
-        """Construct a new tokenizer using the WhitespaceTokenizer framework."""
-
-        super().__init__(component_config)
+    @staticmethod
+    def get_default_config() -> Dict[Text, Any]:
+        """Returns the component's default config."""
+        return {
+            # Flag to check whether to split intents
+            "intent_tokenization_flag": False,
+            # Symbol on which intent should be split
+            "intent_split_symbol": "_",
+            # Regular expression to detect tokens
+            "token_pattern": None,
+        }
 
+    def __init__(self, config: Dict[Text, Any]) -> None:
+        """Initialize the tokenizer."""
+        super().__init__(config)
         self.emoji_pattern = rasa.utils.io.get_emoji_regex()
 
-        if "case_sensitive" in self.component_config:
+        if "case_sensitive" in self._config:
             rasa.shared.utils.io.raise_warning(
                 "The option 'case_sensitive' was moved from the tokenizers to the "
                 "featurizers.",
                 docs=DOCS_URL_COMPONENTS,
             )
 
+    @classmethod
+    def create(
+        cls,
+        config: Dict[Text, Any],
+        model_storage: ModelStorage,
+        resource: Resource,
+        execution_context: ExecutionContext,
+    ) -> WhitespaceTokenizer:
+        """Creates a new component (see parent class for full docstring)."""
+        # Path to the dictionaries on the local filesystem.
+        return cls(config)
+
     def remove_emoji(self, text: Text) -> Text:
         """Remove emoji if the full text, aka token, matches the emoji regex."""
         match = self.emoji_pattern.fullmatch(text)
