@@ -63,16 +63,20 @@ TCP_PROTOCOL = "TCP"
 DEFAULT_SENDER_ID = "default"
 UTTER_PREFIX = "utter_"
 
+ASSISTANT_ID_KEY = "assistant_id"
+ASSISTANT_ID_DEFAULT_VALUE = "placeholder_default"
+
+CONFIG_MANDATORY_COMMON_KEYS = [ASSISTANT_ID_KEY]
 CONFIG_AUTOCONFIGURABLE_KEYS_CORE = ["policies"]
 CONFIG_AUTOCONFIGURABLE_KEYS_NLU = ["pipeline"]
 CONFIG_AUTOCONFIGURABLE_KEYS = (
     CONFIG_AUTOCONFIGURABLE_KEYS_CORE + CONFIG_AUTOCONFIGURABLE_KEYS_NLU
 )
-CONFIG_KEYS_CORE = ["policies"]
-CONFIG_KEYS_NLU = ["language", "pipeline"]
+CONFIG_KEYS_CORE = ["policies"] + CONFIG_MANDATORY_COMMON_KEYS
+CONFIG_KEYS_NLU = ["language", "pipeline"] + CONFIG_MANDATORY_COMMON_KEYS
 CONFIG_KEYS = CONFIG_KEYS_CORE + CONFIG_KEYS_NLU
-CONFIG_MANDATORY_KEYS_CORE: List[Text] = []
-CONFIG_MANDATORY_KEYS_NLU = ["language"]
+CONFIG_MANDATORY_KEYS_CORE: List[Text] = [] + CONFIG_MANDATORY_COMMON_KEYS
+CONFIG_MANDATORY_KEYS_NLU = ["language"] + CONFIG_MANDATORY_COMMON_KEYS
 CONFIG_MANDATORY_KEYS = CONFIG_MANDATORY_KEYS_CORE + CONFIG_MANDATORY_KEYS_NLU
 
 # Keys related to Forms (in the Domain)
