@@ -127,8 +127,7 @@ class RasaCustomLayer(tf.keras.layers.Layer):
         """
         kernel = layer_to_replace.get_kernel().numpy()
         bias = layer_to_replace.get_bias()
-        use_bias = False if bias is None else True
-        if use_bias:
+        if bias is not None:
             bias = bias.numpy()
         units = layer_to_replace.get_units()
         # split kernel by feature sizes to update the layer accordingly
@@ -155,12 +154,12 @@ class RasaCustomLayer(tf.keras.layers.Layer):
         # stack each merged weight to form a new weight tensor
         new_weights = np.vstack(merged_weights)
         kernel_init = tf.constant_initializer(new_weights)
-        bias_init = tf.constant_initializer(bias) if use_bias else None
+        bias_init = tf.constant_initializer(bias) if bias is not None else None
         new_layer = layers.DenseForSparse(
             name=f"sparse_to_dense.{attribute}_{feature_type}",
             reg_lambda=reg_lambda,
             units=units,
-            use_bias=use_bias,
+            use_bias=bias is not None,
             kernel_initializer=kernel_init,
             bias_initializer=bias_init,
         )
@@ -233,7 +232,7 @@ class ConcatenateSparseDenseFeatures(RasaCustomLayer):
         )
 
         # Prepare dropout and sparse-to-dense layers if any sparse tensors are expected
-        self._tf_layers = {}
+        self._tf_layers: Dict[Text, tf.keras.layers.Layer] = {}
         if any([signature.is_sparse for signature in feature_type_signature]):
             self._prepare_layers_for_sparse_tensors(attribute, feature_type, config)
 
@@ -404,7 +403,7 @@ class RasaFeatureCombiningLayer(RasaCustomLayer):
 
         super().__init__(name=f"rasa_feature_combining_layer_{attribute}")
 
-        self._tf_layers = {}
+        self._tf_layers: Dict[Text, tf.keras.layers.Layer] = {}
 
         # Prepare sparse-dense combining layers for each present feature type
         self._feature_types_present = self._get_present_feature_types(
